@@ -2,22 +2,21 @@ import torch
 import torch.nn as nn
 from torch.nn import Module as Module
 from collections import OrderedDict
-from .anti_aliasing import AntiAliasDownsampleLayer
-from .avg_pool import FastAvgPool2d
-from .general_layers import SEModule, SpaceToDepthModule
-from .inplace_abn import InplaceAbn
+from .layers.tresnetv1.anti_aliasing import AntiAliasDownsampleLayer
+from .layers.tresnetv1.avg_pool import FastAvgPool2d
+from .layers.tresnetv1.general_layers import SEModule, SpaceToDepthModule
+from .layers.tresnetv1.inplace_abn import InplaceAbn
 
 from .registry import register_model
 from .utils import _set_config, _load
 
 url_cfgs = {
     'tresnet_m_21k' : 'https://github.com/jitdee-ai/darmo/releases/download/0.0.1/tresnet_m_miil_21k.pth',
-    'tresnet_l_21k' : 'https://github.com/jitdee-ai/darmo/releases/download/0.0.1/tresnet_l_v2_miil_21k.pth',
 }
 
 @register_model
 def tresnet_m_21k(pretrained=True, num_classes=11221, auxiliary=False):
-    model_params = {'num_classes': num_classes}
+    model_params = {'num_classes': 11221}
 
     config = _set_config(_config={}, name= 'tresnet_m_21k', first_channels=46, layers=14, auxiliary=auxiliary, 
                         genotype=None, last_bn=False, pretrained=pretrained, num_classes=11221)
@@ -26,17 +25,6 @@ def tresnet_m_21k(pretrained=True, num_classes=11221, auxiliary=False):
     _load(config, base_net, url_cfgs, True)
     return base_net
 
-@register_model
-def tresnet_l_21k(pretrained=True, num_classes=11221, auxiliary=False):
-    model_params = {'num_classes': num_classes}
-
-    config = _set_config(_config={}, name= 'tresnet_l_21k', first_channels=46, layers=14, auxiliary=auxiliary, 
-                        genotype=None, last_bn=False, pretrained=pretrained, num_classes=11221)
-
-    base_net = TResnetM(model_params)
-    _load(config, base_net, url_cfgs, True)
-    return base_net
-
 class bottleneck_head(nn.Module):
     def __init__(self, num_features, num_classes, bottleneck_features=200):
         super(bottleneck_head, self).__init__()
@@ -244,14 +232,4 @@ def TResnetM(model_params):
     in_chans = 3
     num_classes = model_params['num_classes']
     model = TResNet(layers=[3, 4, 11, 3], num_classes=num_classes, in_chans=in_chans)
-    return model
-
-
-def TResnetL(model_params):
-    """Constructs a large TResnet model.
-    """
-    in_chans = 3
-    num_classes = model_params['num_classes']
-    layers_list = [3, 4, 23, 3]
-    model = TResNet(layers=layers_list, num_classes=num_classes, in_chans=in_chans, first_two_layers=Bottleneck)
     return model
\ No newline at end of file
